# Recent Precedential Opinions (Last 30 Days)

### As of February 24, 2012 12:20:09

Recent Not Precedential Opinions
Precedential Opinions Filed Today
Not Precedential Opinions Filed Today
Search for Opinions
Search for Dockets - PACER System

Opinions now in PDF format and require Adobe Acrobat Reader
Problems opening PDF files ?

Filed 02/24/12, No. 10-4092
USA v. Neal Saferstein
USDC for the Eastern District of Pennsylvania
Filed 02/24/12, No. 10-4092
USA v. Neal Saferstein
USDC for the Eastern District of Pennsylvania
Filed 02/24/12, No. 09-4541
Maribel Delrio-Mocci v. Connolly Properties Inc
USDC for the District of New Jersey
Filed 02/24/12, No. 09-3586
Nakia Garrus v. Secretary PA Dept Corr
USDC for the Eastern District of Pennsylvania
Filed 02/22/12, No. 11-1136
USA v. Ahmoi Lewis
USDC for the District Court of the Virgin Islands
Filed 02/14/12, No. 10-3234
Jose Castro v. Atty Gen USA
Agency
Filed 02/13/12, No. 08-2365
Darryl Baker v. Govt Officials
USDC for the Western District of Pennsylvania
Filed 02/13/12, No. 08-2288
Darryl Baker v. Govt Officials
USDC for the Western District of Pennsylvania
Filed 02/13/12, No. 06-4732
Ronald Long v. Atlantic City Police Departmen
USDC for the District of New Jersey
Filed 02/09/12, No. 08-2174
Shawn Sharp v. Johnson
USDC for the Western District of Pennsylvania
Filed 02/07/12, No. 09-3467
USA v. Christopher Wright
USDC for the Eastern District of Pennsylvania
Filed 02/02/12, No. 11-2246
Marcavage v. National Park Service
USDC for the Eastern District of Pennsylvania
Filed 01/31/12, No. 10-3916
Debra Haybarger v. William Mancino
USDC for the Western District of Pennsylvania
Filed 01/27/12, No. 10-4133
Han Tak Lee v. Steve Glunt
USDC for the Middle District of Pennsylvania
Filed 01/26/12, No. 11-1664
Allstate Property & Casualty v. Larry Squires
USDC for the Western District of Pennsylvania
Filed 01/24/12, No. 11-1554
Randy Long v. Tommy Hilfiger USA Inc
USDC for the Western District of Pennsylvania
Filed 01/24/12, No. 11-1406
Mabey Bridge Shore v. Allen Biehler
USDC for the Middle District of Pennsylvania
Filed 07/02/09, No. 08-9050
IN RE: Complaint of Judicial Misconduct v.